@@ -4,8 +4,8 @@ create_xgboost <- function(hyperparams, task){
   trees <- if (hyperparams$trees_tune) tune::tune() else as.integer(hyperparams$hyperparams_constant$trees)
   min_n <- if (hyperparams$min_n_tune) tune::tune() else as.integer(hyperparams$hyperparams_constant$min_n)
   tree_depth <- if (hyperparams$tree_depth_tune) tune::tune() else as.integer(hyperparams$hyperparams_constant$tree_depth)
-  learn_rate <- if (hyperparams$learn_rate_tune) tune::tune() else as.integer(hyperparams$hyperparams_constant$learn_rate)
-  loss_reduction <- if (hyperparams$loss_reduction_tune) tune::tune() else as.integer(hyperparams$hyperparams_constant$loss_reduction)
+  learn_rate <- if (hyperparams$learn_rate_tune) tune::tune() else as.numeric(hyperparams$hyperparams_constant$learn_rate)
+  loss_reduction <- if (hyperparams$loss_reduction_tune) tune::tune() else as.numeric(hyperparams$hyperparams_constant$loss_reduction)
 
   model = parsnip::boost_tree(
 
