@@ -10,7 +10,7 @@ get_predictions_binary <- function(analysis_object, new_data = "test"){
 
   if (new_data == "all"){
 
-    data_sets = c("train", "validation", "test")
+      data_sets = c("train", "test")
 
     temp = list()
 
@@ -26,7 +26,7 @@ get_predictions_binary <- function(analysis_object, new_data = "test"){
       temp[[data_set]] = predictions
     }
 
-    predictions = rbind(temp[["train"]], temp[["validation"]], temp[["test"]])
+    predictions = rbind(temp[["train"]], temp[["test"]])
 
   } else {
 
@@ -161,37 +161,40 @@ plot_lift_curve_binary <- function(predictions, new_data = "all"){
     return(curve_plot)
 
   }
-
-
 }
 
 plot_dist_probs_binary <- function(predictions, new_data = "test"){
 
-  positive_class = levels(predictions$y)[2]
-
-  predicted = paste0(".pred_", positive_class)
+  positive_class <- levels(predictions$y)[2]
+  predicted       <- paste0(".pred_", positive_class)
 
   p <- predictions %>%
     dplyr::filter(data_set == new_data) %>%
     dplyr::group_by(y) %>%
-    ggplot2::ggplot(ggplot2::aes(x = .data[[predicted]], fill = .data[["y"]])) +
+    ggplot2::ggplot(
+      ggplot2::aes(
+        x    = !!rlang::sym(predicted),
+        fill = y
+      )
+    ) +
     ggplot2::geom_density(alpha = 0.5) +
-    ggplot2::labs(title = paste0("Probability Distribution by Class (",new_data, " data)") ,
-                  x = "Predicted Probability",
-                  y = "Density",
-                  fill = "Class") +
+    ggplot2::labs(
+      title = paste0("Probability Distribution by Class (", new_data, " data)"),
+      x     = "Predicted Probability",
+      y     = "Density",
+      fill  = "Class"
+    ) +
     ggplot2::theme_minimal()
 
   return(p)
 
 }
 
+
 plot_calibration_curve_binary <- function(predictions, new_data = "test"){
 
   positive_class = levels(predictions$y)[2]
 
-#' @importFrom rlang sym .data
-
   predicted = rlang::sym(paste0(".pred_", positive_class))
 
   p <- predictions %>%
